
CREATE TABLE Mitarbeiter
(
	SVNR					VARCHAR2(10) PRIMARY KEY,
	Name					VARCHAR2(256) NOT NULL,
	GebDat					DATE NOT NULL,
	Gehalt					NUMBER(16) NOT NULL
);

CREATE TABLE Austraeger
(
	SVNR					VARCHAR2(10) PRIMARY KEY,
	Fahrzeug				NUMBER(1) NOT NULL CHECK (Fahrzeug BETWEEN 0 AND 1)
);

CREATE TABLE Themengebiet
(
	Name					VARCHAR2(256) PRIMARY KEY,
	Beschreibung				VARCHAR2(256)
);

CREATE TABLE Redakteur
(
	SVNR					VARCHAR2(10) PRIMARY KEY,
	Dienstjahre				NUMBER(2) NOT NULL,
	Einstelldatum				DATE NOT NULL
);

CREATE TABLE Spezialgebiet
(
	SVNR					VARCHAR2(10) PRIMARY KEY,
	Name					VARCHAR2(256) REFERENCES Themengebiet(Name) NOT NULL,
	Praemie					NUMBER(4) NOT NULL,
	FOREIGN KEY (SVNR) REFERENCES Redakteur(SVNR)
);

CREATE TABLE Zeitschrift 
(
	Genre					VARCHAR2(64),
	Name					VARCHAR2(64),
	Bekanntheit				NUMBER(3) NOT NULL,
	Einfuehrungsdatum		DATE NOT NULL,
	PRIMARY KEY(Genre, Name)
);

CREATE TABLE Zeitung
(
	Genre					VARCHAR2(64),
	Name					VARCHAR2(64),
	Budget					NUMBER(8) NOT NULL,
	Leser					NUMBER(8) NOT NULL,
	ChefredakteurSVNR		VARCHAR2(10) NOT NULL REFERENCES Redakteur(SVNR),
	PRIMARY KEY(Genre, Name),
	FOREIGN KEY(Genre, Name) REFERENCES Zeitschrift(Genre, Name)
);

CREATE TABLE Magazin
(
	Genre					VARCHAR2(64),
	Name					VARCHAR2(64),
	Untertitel				VARCHAR2(256),
	Periode					VARCHAR2(16),
	PRIMARY KEY(Genre, Name),
	FOREIGN KEY(Genre, Name) REFERENCES Zeitschrift(Genre, Name)
);

CREATE TABLE Ende
(
	Genre					VARCHAR2(64),
	Name					VARCHAR2(64),
	Enddatum				DATE NOT NULL,
	PRIMARY KEY(Genre, Name),
	FOREIGN KEY(Genre, Name) REFERENCES Zeitschrift(Genre, Name)
);

CREATE TABLE Kunde
(
	ID						NUMBER(8) PRIMARY KEY,
	Name					VARCHAR2(256) NOT NULL,
	Adresse					VARCHAR2(1024) NOT NULL,
	Telefon					VARCHAR2(32) NOT NULL,
	Typ						VARCHAR2(16) NOT NULL
);

CREATE TABLE Abonnement
(
	ID				NUMBER(8) PRIMARY KEY,
	Gebuehr				NUMBER(4) NOT NULL,
	Anfang				DATE NOT NULL,
	Ende				DATE NULL,
	KundenID			NUMBER(8) NOT NULL REFERENCES Kunde(ID),
	ZeitschriftGenre		VARCHAR2(64) NOT NULL,
	ZeitschriftName			VARCHAR2(64) NOT NULL,
	FOREIGN KEY(ZeitschriftGenre, ZeitschriftName) REFERENCES Zeitschrift(Genre, Name)
);

CREATE TABLE Lieferung
(
	ID				NUMBER(8),
	Datum				DATE,
	Persoenlich			NUMBER(1) NOT NULL CHECK (Persoenlich BETWEEN 0 AND 1),
	AustraegerSVNR			VARCHAR2(10) NOT NULL REFERENCES Austraeger(SVNR),
	PRIMARY KEY(ID, Datum)
);

CREATE TABLE traegt_aus
(
	Genre					VARCHAR2(64),
	Name					VARCHAR2(64),
	SVNR					VARCHAR2(10) REFERENCES Austraeger(SVNR),
	PRIMARY KEY(Genre, Name, SVNR),
	FOREIGN KEY(Genre, Name) REFERENCES Zeitschrift(Genre, Name)
);

CREATE TABLE arbeitet
(
	Genre					VARCHAR2(64),
	Name					VARCHAR2(64),
	SVNR					VARCHAR2(10) REFERENCES Redakteur(SVNR),
	PRIMARY KEY(Genre, Name, SVNR),
	FOREIGN KEY(Genre, Name) REFERENCES Zeitschrift(Genre, Name)
);

CREATE TABLE zustaendig
(
	Genre		VARCHAR2(64),
	Name		VARCHAR2(64),
	Thema		VARCHAR2(1024) REFERENCES Themengebiet(Name),
	SVNR		VARCHAR2(10) REFERENCES Redakteur(SVNR),
	PRIMARY KEY(Genre, Name, Thema, SVNR),
	FOREIGN KEY(Genre, Name) REFERENCES Magazin(Genre, Name)
);
